@@ -4,67 +4,12 @@ from typing import TYPE_CHECKING, Dict, Union, Generator, Any
 from aiohttp import abc, hdrs, web
 from aiohttp.web_exceptions import HTTPMethodNotAllowed
 
+from cenao.errors import ViewError, ServerError
+
 if TYPE_CHECKING:
     from cenao.app import Application, AppFeature
 
 
-class ViewError(Exception):
-    code: int
-    status: int = 500
-    reason_format: str = ''
-
-    @classmethod
-    def name(cls) -> str:
-        return cls.__name__[:-5]
-
-    def __repr__(self):
-        return '<{} code={} reason={!r}>'.format(
-            self.__class__.__name__, self.code, self.reason()
-        )
-
-    def reason(self):
-        return self.reason_format.format(*self.args)
-
-    def error_msg(self):
-        return '{:d}: {}'.format(self.code, self.reason())
-
-
-class ClientError(ViewError):
-    code = 4000
-    status = 400
-    reason_format = 'Unknown client error'
-
-
-class ClientUnauthorizedError(ViewError):
-    code = 4001
-    status = 401
-    reason_format = 'Unauthorized error'
-
-
-class ClientForbiddenError(ViewError):
-    code = 4003
-    status = 403
-    reason_format = 'Forbidden error'
-
-
-class ClientMethodNotAllowedError(ViewError):
-    code = 4005
-    status = 405
-    reason_format = 'Method not allowed error'
-
-
-class ClientConflictError(ViewError):
-    code = 4009
-    status = 409
-    reason_format = 'Conflict error'
-
-
-class ServerError(ViewError):
-    code = 5000
-    status = 500
-    reason_format = 'Unknown server error'
-
-
 class View(abc.AbstractView):
     ROUTE: str
 
@@ -105,8 +50,8 @@ class View(abc.AbstractView):
                 'error': ve.error_msg(),
                 'reason': ve.reason(),
             }, status=ve.status)
-        except Exception:
-            self.logger.exception('Got an exception while handling request')
+        except Exception as e:
+            self.logger.warning('Got an exception while handling request: %r', e)
             e = ServerError()
             return web.json_response({
                 'ok': False,
